@@ -267,8 +267,8 @@ class DailyScraper(Scraper):
                         'linux64': r'\.%(EXT)s$',
                         'mac': r'\.%(EXT)s$',
                         'mac64': r'\.%(EXT)s$',
-                        'win32': r'(\.installer)?\.%(EXT)s$',
-                        'win64': r'(\.installer)?\.%(EXT)s$'}
+                        'win32': r'(\.installer)\.%(EXT)s$',
+                        'win64': r'(\.installer)\.%(EXT)s$'}
         regex = regex_base_name + regex_suffix[self.platform]
 
         return regex % {'APP': self.application,
@@ -691,7 +691,7 @@ def cli():
                      default='mozilla-central',
                      metavar='BRANCH',
                      help='Name of the branch, default: "%default"')
-    parser.add_option('--build-id',
+    group.add_option('--build-id',
                       dest='build_id',
                       default=None,
                       metavar='BUILD_ID',
